function F0_make_cosmo(subj_num)
% generates cosmo data structures from EEGlab data structures
   
    data_fold = './clean_data/';
    run('/rds/projects/2018/hickeycm-insense/MATLAB_toolboxes/eeglab14_1_2b/eeglab.m');
    run('/rds/projects/2018/hickeycm-insense/MATLAB_toolboxes/CoSMoMVPA-master/mvpa/cosmo_set_path.m');
    subj_str = ['P' sprintf('%02.f',subj_num)];
    input_fold = fullfile(data_fold,'Ater_allepochs_clean_final', subj_str);
    input_file = [subj_str, '_lp_hp_epch_intrp_bl_clean.set'];

    savedir = fullfile(data_fold,'F0_exp_cosmo_structures');
    if ~exist(savedir,'dir')
        mkdir(savedir);
    end
    
    EEG = pop_loadset('filename',input_file,'filepath',input_fold);
    
    % keep only EEG channels, baseline on 200 ms prestim
    EEG = pop_select(EEG,'channel',1:128);
    EEG = pop_resample(EEG, 200)
    baseline_interval = [-200 0]; 
    EEG = pop_rmbase(EEG,baseline_interval);
    epoch_length = [-0.2 1]; 

    EEG_orig = EEG; 
        
    % cheat sheet for trigger codes
    % TxxD describes when target is at top position, distractor is to right
    % of fixation

    % TxxD: 10
    % xxTD: 11
    % xDTx: 12
    % TDxx: 13
    % DxxT: 20
    % xxDT: 21
    % DTxx: 22
    % xTDx: 23
    % 
    % target category codes. 
    % T1_D2: 42
    % T1_D3: 43
    % T1_D4: 44
    % T2_D1: 51
    % T2_D3: 53
    % T2_D4: 54
    % T3_D1: 61
    % T3_D2: 62
    % T3_D4: 64
    % T4_D1: 71
    % T4_D2: 72
    % T4_D3: 73
    
    % identify stim events, rename with cat-specific id
    EEG = EEG_orig; 
    base_trigger = 10000;
    cat_acc = cell(4,1);
    for i = 1:size(EEG.event,2)-4
        % is accurate
        if EEG.event(i+4).type == 4
            new_trigger = base_trigger + 100000; 
            EEG.event(i).RT = define_triggers
            EEG.event(i+4).latency - EEG.event(i).latency; 
            EEG.event(i).ACC = 1; 
        else
            new_trigger = base_trigger + 200000; 
            EEG.event(i).ACC = 0; 
        end

        increment_value = 0;

        % code for stimuli positions
        % in reordering, top-left = 1000, top-right = 2000, bottom-left =
        % 3000, bottom-right = 4000 etc
        if EEG.event(i).type == 10
            % top target, left distractor
            increment_value = 4300; 
        elseif EEG.event(i).type == 11
            % bottom target, left distractor
            increment_value = 2300; 
        elseif EEG.event(i).type == 12
            % bottom target, right distractor
            increment_value = 2100; 
        elseif EEG.event(i).type == 13
            % top target, right distractor
            increment_value = 4100; 
        
        elseif EEG.event(i).type == 20
            % left target, top distractor
            increment_value = 3400; 
        elseif EEG.event(i).type == 21
            % left target, bottom distractor
            increment_value = 3200; 
        elseif EEG.event(i).type == 22
            % right target, top distractor
            increment_value = 1400; 
        elseif EEG.event(i).type == 23
            % right target, bottom distractor
            increment_value = 1200; 
        end

        % code for target category
        if EEG.event(i+1).type > 40 && EEG.event(i+1).type < 50
            % T1
            increment_value = increment_value + 10; 
        elseif EEG.event(i+1).type > 50 && EEG.event(i+1).type < 60
            % T2
            increment_value = increment_value + 20; 
        elseif EEG.event(i+1).type > 60 && EEG.event(i+1).type < 70
            % T3
            increment_value = increment_value + 30; 
        elseif EEG.event(i+1).type > 70 && EEG.event(i+1).type < 80
            % T4
            increment_value = increment_value + 40; 
        end

        % code for dist category
        if mod(EEG.event(i+1).type, 10) == 1
            % D1
            increment_value = increment_value + 1; 
        elseif mod(EEG.event(i+1).type, 10) == 2
            % D2
            increment_value = increment_value + 2; 
        elseif mod(EEG.event(i+1).type, 10) == 3
            % D3
            increment_value = increment_value + 3; 
        elseif mod(EEG.event(i+1).type, 10) == 4
            % D4
            increment_value = increment_value + 4; 
        end

        EEG.event(i).type = new_trigger + increment_value; 
    end
    
    % for each category at each two lateral positions
    counter = 1; 
    events_list = [EEG.event.type];
    [valid_codes, num_events] = deal([]);
    for pos = [12 14 23 21 34 32 41 43]
        % eg, 12 is right target, bottom dist etc, has event code 1112xx
        for cat = [12 13 14 21 23 24 31 32 34 41 42 43]
            % eg, 1 T1, 2 is D2; right target, bottom dist, T1, D2 is 111212
            event_code = 110000 + (pos*100) + cat; 
            if any(events_list == event_code)
                epochs{counter} = pop_epoch(EEG, {event_code}, epoch_length)
                valid_codes = [valid_codes; event_code];
                num_events = [num_events; sum(events_list == event_code)];
                counter = counter + 1; 
            end
        end
    end

    epochs_LT = epochs([1:16 41:48 33:40]); 
                     % pos 12 14 32 34
                     % targ right, bottom dist
                     % targ right, top dist
                     % targ left, bottom dist
                     % targ left, top dist
    epochs_LD = epochs([25:32 17:24 49:64]); 
                     % pos 21 23 41 43
                     % dist right, bottom targ
                     % dist right, top targ
                     % dist left, bottom targ
                     % dist left, top targ

    LT = make_cosmo(epochs_LT); 
    LD = make_cosmo(epochs_LD); 

    save(fullfile(savedir,[subj_str '_cosmo_structs.mat']),'LT', 'LD');
end
    
    
function ds = make_cosmo(epochs)
    ds = struct();
    epoch_counter = 1; 
    for pos = 1:4
        % right, bottom
        % right, top
        % left, bottom
        % left, top
        for targ_cat = 1:4
            for dist_cat = 1:2
                % 2 4
                % 1 3

                if targ_cat == 1 || targ_cat == 3
                    if dist_cat == 1
                        cond = ['P' num2str(pos) 'Lateral' num2str(targ_cat) 'Central2'];
                        lat_cat_label = targ_cat; 
                        central_cat_label = 2; 
                    else
                        cond = ['P' num2str(pos) 'Lateral' num2str(targ_cat) 'Central4'];
                        lat_cat_label = targ_cat; 
                        central_cat_label = 4; 
                    end
                elseif targ_cat == 2 || targ_cat == 4
                    if dist_cat == 1
                        cond = ['P' num2str(pos) 'Lateral' num2str(targ_cat) 'Central1'];
                        lat_cat_label = targ_cat; 
                        central_cat_label = 1;                         
                    else
                        cond = ['P' num2str(pos) 'Lateral' num2str(targ_cat) 'Central3'];
                        lat_cat_label = targ_cat; 
                        central_cat_label = 3; 
                    end
                end

                % Convert EEGLab struct into COSMOMVPA struct
                data_tmp = permute(epochs{epoch_counter}.data,[3, 1, 2]);
                ds.(cond) = cosmo_flatten(data_tmp,{'chan','time'},{{epochs{epoch_counter}.chanlocs(:).labels},epochs{epoch_counter}.times}); 
                ds.(cond).sa.lat_cat = lat_cat_label * ones(size(ds.(cond).samples,1),1);
                ds.(cond).sa.central_cat = central_cat_label * ones(size(ds.(cond).samples,1),1);
                ds.(cond).sa.pos = pos*ones(size(ds.(cond).samples,1),1);

                ds.(cond).sa.targets = ones(size(ds.(cond).samples,1),1);
                ds.(cond).sa.chunks = ones(size(ds.(cond).samples,1),1);
                cosmo_check_dataset(ds.(cond));
                epoch_counter = epoch_counter + 1; 
            end
        end
    end
end
    


function ds_out = get_RTs(ds_in, epochs_in)
    ds_out = ds_in; 
    % extract RTs and store in ds structure
    epoch_counter = 1; 
    for i = 1:2
        for j = 1:4
            cdn_id = ['P' num2str(i) 'C' num2str(j)]; 
            RTs = []; 
            for k = 1:epochs_in{epoch_counter}.trials
                RTs(k) = epochs_in{epoch_counter}.epoch(k).eventRT{1};
            end
            ds_out.(cdn_id).a.RT = RTs; 
            epoch_counter = epoch_counter + 1; 
        end
    end
    for i = 1:4
        cdn_id_target = ['C' num2str(i)];
        cdn_id_sample1 = ['P1C' num2str(i)];
        cdn_id_sample2 = ['P2C' num2str(i)];
        ds_out.(cdn_id_target).a.RT = [ds_out.(cdn_id_sample1).a.RT ds_out.(cdn_id_sample2).a.RT];
    end
end

   

