function F1_searchlight(input_id)
% note that inpud_id identifies both subject number and condition ID, 
% so script needs to be run 4 times per subject.
% This is to facilitate run on cluster (see batchF1.sh). 

    subj_num = ceil(input_id ./ 4); 
    disp(['sub num ' num2str(subj_num)]);
    condition_counter = mod(input_id, 4) + 1;     
    disp(['condition ' num2str(condition_counter)]);

    base_fold = './clean_data/'; 
    
    run(['/rds/projects/2018/hickeycm-insense/MATLAB_toolboxes/CoSMoMVPA-master/mvpa/cosmo_set_path.m']);
    data_fold = [base_fold 'EEG_exp_Kisal/DATA'];
    subj_str = ['P' sprintf('%02.f',subj_num)]
    
    if condition_counter == 1
        % decoding of target category at lateral locations
        load(fullfile(data_fold,'F0_exp_cosmo_structures',[subj_str '_cosmo_structs_exp_2pos_targ_new.mat']),'ds');
    elseif condition_counter == 2
        % decoding of distractor category at lateral locations
        load(fullfile(data_fold,'F0_exp_cosmo_structures',[subj_str '_cosmo_structs_exp_2pos_dist_new.mat']),'ds');
    elseif condition_counter == 3
        % LDVT
        load(fullfile(data_fold,'F0_exp_cosmo_structures',[subj_str '_cosmo_structs_exp_LDVT_new.mat']),'ds');
    elseif condition_counter == 4
        % LTVD
        load(fullfile(data_fold,'F0_exp_cosmo_structures',[subj_str '_cosmo_structs_exp_LTVD_new.mat']),'ds');
    end

    save_fold = fullfile(data_fold,'F_classifications',subj_str);
    
    if ~exist(save_fold,'dir')
        mkdir(save_fold);
    end
    
    % 4-class decoding of category, left / right locations
    if condition_counter <= 2
        % lateral target or distractor, ignoring other stim

        % the RT field breaks some internal cosmo functions, strip it
        % before continuing
        if isfield(ds.C1.a, 'RT')
            ds.C1.a = rmfield(ds.C1.a, 'RT'); 
            ds.C2.a = rmfield(ds.C2.a, 'RT'); 
            ds.C3.a = rmfield(ds.C3.a, 'RT'); 
            ds.C4.a = rmfield(ds.C4.a, 'RT'); 
        end

        ds_test = cosmo_stack({ds.C1, ds.C2, ds.C3, ds.C4});
        ds_test.sa.chunks = (1:size(ds_test.samples,1))';
    elseif condition_counter == 3
         % lateral distractor, vertical target
        ds_test = cosmo_stack({ds.LD_VT_C1, ds.LD_VT_C2, ds.LD_VT_C3, ds.LD_VT_C4});
    elseif condition_counter == 4
        % lateral target, vertical distractor
        ds_test = cosmo_stack({ds.LT_VD_C1, ds.LT_VD_C2, ds.LT_VD_C3, ds.LT_VD_C4});
    end
        
    % 20 chunks, 3 samples in each iteration for 1140 iterations
    ds_test.sa.chunks = [1:numel(ds_test.sa.chunks)]';
    nchunks = 20; 
    ds_test.sa.chunks = cosmo_chunkize(ds_test, nchunks);
    ds_test.sa.targets = ds_test.sa.category; 
    
    time_radius = 8;
    time_nbrhood = cosmo_interval_neighborhood(ds_test,'time',...
        'radius',time_radius);
    nbrhood = cosmo_cross_neighborhood(ds_test,{time_nbrhood});
    partitions = cosmo_nchoosek_partitioner(ds_test,3); 
    
    % S15 has problem here, no class 3 in the test set for one
    % instance. Force it through below. 
    if subj_num == 15
        partitions.test_indices{686} = partitions.test_indices{685}; 
        partitions.train_indices{686} = partitions.train_indices{685}; 
    end

	partitions=cosmo_balance_partitions(partitions, ds_test);

    % note use of local 'activ' version of measure to retain both folds
    % and classifier forward model
    measure=@cosmo_crossvalidation_measure_activ;
    measure_args=struct();
    measure_args.classifier=@cosmo_classify_lda_activ;
    measure_args.partitions=partitions;
    measure_args.normalization = 'zscore';
    measure_args.nproc = inf;
    
    % this outputs a set of cells, one for each worker used in parallel
    % computing 
    decode_res_tmp = cosmo_searchlight_activ(ds_test,nbrhood,measure,measure_args);
    
    % patch together the cells (the data is split into temporal chunks for parallelization)
    working_data = decode_res_tmp{1}; 
    if numel(decode_res_tmp) > 1
        for worker_counter = 2:numel(decode_res_tmp)
            working_data.models = [working_data.models decode_res_tmp{worker_counter}.models]; 
            working_data.samples = [working_data.samples decode_res_tmp{worker_counter}.samples]; 
            working_data.samples2 = [working_data.samples2 decode_res_tmp{worker_counter}.samples2]; 
        end
    end
    
    % extract only weights applied to covariance matrix, throw away rest of LDA model parameters to
    % reduce size
    models = []; 
    confusion_data = []; 
    % for each timepoint
    for i = 1:numel(working_data.models)
        average = []; 
        % for each set of folds
        for j = 1:numel(working_data.models{i})
            average(j,:,:) = working_data.models{i}{j}.activation_cov; 
            confusion_data{i}{j}(1,:) = working_data.models{i}{j}.predicted_class; 
            confusion_data{i}{j}(2,:) = working_data.models{i}{j}.actual_class; 
            MI(j,i) = MutualInfo([working_data.models{i}{j}.predicted_class';...
                working_data.models{i}{j}.actual_class']);
        end
        
        models{i} = squeeze(mean(average,1)); 
        disp(i)
        
    end
    
    working_data.models = models; 
    working_data.confusion_data = confusion_data; 
    working_data.MI = MI; 

    decode_res = working_data; 

    if condition_counter == 1
        save(fullfile(save_fold,[subj_str '_decode_4cat_2pos_exp_sl_targ_new.mat']),'decode_res', 'partitions', 'ds', '-v7.3');
    elseif condition_counter == 2
        save(fullfile(save_fold,[subj_str '_decode_4cat_2pos_exp_sl_dist_new.mat']),'decode_res', 'partitions', 'ds', '-v7.3');
    elseif condition_counter == 3
        save(fullfile(save_fold,[subj_str '_decode_4cat_2pos_exp_sl_LD_new.mat']),'decode_res', 'partitions', 'ds', '-v7.3');
    elseif condition_counter == 4
        save(fullfile(save_fold,[subj_str '_decode_4cat_2pos_exp_sl_LT_new.mat']),'decode_res', 'partitions', 'ds', '-v7.3');
    end
    
end

