clear; close all; 

do_MI = false; 

load('F2_exp_corr_searchlight.mat')

% save timeline for later
save('timeline.mat', 'timeline');
load('chanlocs.mat'); 

good_subs = 1:44

num_iterations = 1000; 

ipsicon_sample(1,:,:,:) = ipsicon_sample_targ; 
ipsicon_sample(2,:,:,:) = ipsicon_sample_dist;
ipsicon_sample(3,:,:,:) = ipsicon_sample_LT; 
ipsicon_sample(4,:,:,:) = ipsicon_sample_LD;

if do_MI
    classify_sample(1,:,:,:) = classify_MI_targ; 
    classify_sample(2,:,:,:) = classify_MI_dist;
    classify_sample(3,:,:,:) = classify_MI_LT; 
    classify_sample(4,:,:,:) = classify_MI_LD;
else
    classify_sample(1,:,:,:) = classify_sample_targ; 
    classify_sample(2,:,:,:) = classify_sample_dist;
    classify_sample(3,:,:,:) = classify_sample_LT; 
    classify_sample(4,:,:,:) = classify_sample_LD;
end

ipsicon_sample = ipsicon_sample(:,good_subs,:,:); 
classify_sample = classify_sample(:,good_subs,:,:); 

temp1 = squeeze(classify_sample(1,:,:,:)); 
temp2 = squeeze(classify_sample(2,:,:,:)); 

corrs = []; 
ps = []; 
for i = 1:44
    for j = 1:240
        [corrs(i,j) ps(i,j)] = corr(temp1(i,:,j)', temp2(i,:,j)');
    end
end

figure; plot(timeline, mean(corrs,1))


% condition map: 1 = LT, 2 = LD, 3 = LT_VD, 4 = LD_VT
% in second two conditions, decoding accuracy is for the vertical stimulus

% time duration 
time_duration_ms_N2pc = 173:298
start_idx = find(timeline > time_duration_ms_N2pc(1),1);
end_idx = find(timeline > time_duration_ms_N2pc(end),1);
time_duration_N2pc = start_idx:end_idx; 

time_duration_ms_classify = time_duration_ms_N2pc;
start_idx = find(timeline > time_duration_ms_classify(1),1);
end_idx = find(timeline > time_duration_ms_classify(end),1);
time_duration_classify = start_idx:end_idx; 

figure; 
rs = zeros(size(good_subs,2),4);
bs = zeros(size(good_subs,2),2,4);

mean_fits = []; 

for working_condition = 1:4

    % set up figure and labels
    if working_condition == 1
        label = 'lateral target'; 
    elseif working_condition == 2
        label = 'lateral distractor'
    elseif working_condition == 3 
        label = 'ipsicon: lateral target, accuracy: vertical distractor'
    elseif working_condition == 4
        label = 'ipsicon: lateral distractor, accuracy: vertical target'
    end

    subplot(4, 3, ((working_condition - 1) * 3) + 1);
    hold on; 
    if do_MI
        set(gca, 'xdir', 'reverse', 'YLim', [0 0.15], 'XLim', [-6 6])
    else
        set(gca, 'xdir', 'reverse', 'YLim', [0 0.7], 'XLim', [-6 6])
    end
    disp(label)
    xlabel('ipsicon');
    if do_MI
        ylabel('MI');
    else
        ylabel('classify'); 
    end
    
    % calculate relationship, plot in figure
    for i = 1:numel(good_subs)
        
        rs(i, working_condition) = corr(squeeze(mean(ipsicon_sample(working_condition,i,:,time_duration_N2pc),4)), ...
            squeeze(mean(classify_sample(working_condition,i,:,time_duration_classify),4)), 'type', 'p');
        bs(i,:, working_condition) = regress(squeeze(mean(classify_sample(working_condition,i,:,time_duration_N2pc),4)), ...
            [ones(1140,1) squeeze(mean(ipsicon_sample(working_condition,i,:,time_duration_classify),4))]);
        h = scatter(squeeze(mean(ipsicon_sample(working_condition,i,:,time_duration_N2pc),4)), ...
            squeeze(mean(classify_sample(working_condition,i,:,time_duration_classify),4)), 5, '.');
        lsline;

    end

    % generate fit for average of bs for each iteration
    xFit = linspace(-8, 8, size(ipsicon_sample,3));
    avg_bs = mean(squeeze(bs(:,:,working_condition)),1)

    for i = 1:size(ipsicon_sample,3)
        yFit(i) = avg_bs(1) + (avg_bs(2) * xFit(i)); 
    end
    
    % plot average fit
    plot(xFit, yFit, 'r', 'LineWidth', 3)

    mean_fits(working_condition,1,:) = xFit; 
    mean_fits(working_condition,2,:) = yFit; 

    % stats and title
    [ci bootstats] = bootci(num_iterations, {@mean, rs(:,working_condition)}, 'type', 'per')
    stat_output = 1 - sum(bootstats<0)/num_iterations;
    title([label ': r = ' num2str(mean(rs(:,working_condition))) ' p = ' num2str(stat_output)]);


    %%%%%%%
    % plot ipsicon sample 
    subplot(4, 3, ((working_condition - 1) * 3) + 2);
    hold on;
    %error = std(squeeze(mean(classify_sample(working_condition,good_subs,:,:),3)))./sqrt(numel(good_subs));
    error = [];
    temp = squeeze(mean(ipsicon_sample(working_condition,:,:,:),3)); 
    for error_counter = 1:size(temp,2)
        % SEM equivalent to %68.2 CI
        error(error_counter,:) = bootci(num_iterations, {@mean, temp(:,error_counter)}, 'type', 'per', 'alpha', 0.318); 
    end
    error = error';
    temp = squeeze(mean(mean(ipsicon_sample(working_condition,:,:,:),2),3))'
    for k = 1:size(error,2)
        error(:,k) = error(:,k) - temp(k); 
    end 
    error = abs(flipud(error));
    
    shadedErrorBar(timeline, squeeze(mean(mean(ipsicon_sample(working_condition,:,:,:),2),3))', error)
    plot(timeline, squeeze(mean(mean(ipsicon_sample(working_condition,:,:,:),2),3)), 'b')
    set(gca, 'ydir', 'reverse', 'ylim', [-3 1.5])
    % test over time interval, present stat in title
    stats_data = squeeze(mean(mean(ipsicon_sample(working_condition,:, :, time_duration_N2pc),3),4));
    [ci bootstats] = bootci(num_iterations, {@mean, stats_data}, 'type', 'per')
    stat_output = 1 - sum(bootstats<0)/num_iterations;
    title(['p = ' num2str(stat_output)]);


    %%%%%%%
    % cluster stats for classification over time
    % generate null distribution 
    classify_working_data = squeeze(mean(classify_sample(working_condition,:,:,:),3)) - 0.25;
    cluster_defining_alpha = 0.05; 
    alpha = 0.05;
    % generate label swaps for number good subs
    % this is montecarlo with big sample
    %combinations = logical(dec2bin((1:2^(numel(good_subs)))-1) - '0'); 
    if numel(good_subs) < 24
        combinations = logical(dec2bin((1:2^numel(good_subs))-1) - '0'); 
    else
        combinations = logical(dec2bin((1:2^24)-1) - '0'); 
        combinations = [combinations combinations(:,randperm(24,numel(good_subs)-24))];
    end

    % sample some number of possibilities at random (1000 or smaller number
    % if looking at small set subjects)
    num_iterations = min([num_iterations size(combinations,1)]); 
    null_clusters = []; 
    combinations_sample = combinations(randperm(size(combinations,1), num_iterations),:); 
    for i = 1:size(combinations_sample, 1)
        iteration_data = [classify_working_data(combinations_sample(i,:),:); ...
            (classify_working_data(not(combinations_sample(i,:)),:) * -1)];
        [h p ci stats] = ttest(iteration_data, 0, 'Alpha', cluster_defining_alpha); 
        [labelled, num_regions] = bwlabel(h); 
        measurements = regionprops(labelled, h, 'Area', 'PixelValues');
        if isempty(measurements)
            null_clusters(i) = 0; 
        else
            null_clusters(i) = max([measurements.Area]); 
        end
    end
    null_clusters = sort(null_clusters);
    top_5_percent = null_clusters((end - round(alpha * num_iterations)):end);
    cutoff = top_5_percent(1); 

    % calculate size of clusters (over time) in real data
    [h p ci stats] = ttest(classify_working_data, 0, 'Alpha', cluster_defining_alpha)
    [labelled, num_regions] = bwlabel(h)
    measurements = regionprops(labelled, h, 'Area', 'PixelValues');
    sig_cluster_identifier = h
    for i = 1:numel(measurements)
        if sum(labelled == i) < cutoff
            sig_cluster_identifier(find(labelled == i)) = 0; 
        end
    end

    % plot classify sample 
    subplot(4, 3, ((working_condition - 1) * 3) + 3);
    hold on; 

    %error = std(squeeze(mean(classify_sample(working_condition,good_subs,:,:),3)))./sqrt(numel(good_subs));
    error = [];
    temp = squeeze(mean(classify_sample(working_condition,:,:,:),3)); 
    for error_counter = 1:size(temp,2)
        % SEM equivalent to %68.2 CI
        error(error_counter,:) = bootci(num_iterations, {@mean, temp(:,error_counter)}, 'type', 'per', 'alpha', 0.318); 
    end
    error = error';
    temp = squeeze(mean(mean(classify_sample(working_condition,:,:,:),2),3))'
    for k = 1:size(error,2)
        error(:,k) = error(:,k) - temp(k); 
    end 
    error = abs(flipud(error));
    
    shadedErrorBar(timeline, squeeze(mean(mean(classify_sample(working_condition,:,:,:),2),3))', error)
    plot(timeline, squeeze(mean(mean(classify_sample(working_condition,:,:,:),2),3)), 'r')
    if not(do_MI)
        set(gca, 'ylim', [0.23 0.28])
    end

    % plot identifier for significant clusters
    plot_idx = find(sig_cluster_identifier == 1)
    if not(isempty(plot_idx))
        % identify points where the value jumps
        plot_points = find(((plot_idx(2:end) - plot_idx(1:end-1)) > 1) == 1);

        if not(isempty(plot_points))
            plot_points = sort([1 plot_points plot_points + 1]); 
            % convert from plot_idx indices to plot_idx contents
            plot_points = plot_idx(plot_points); 
            % if there are an uneven number of points, then line needs to be
            % plotted to end of plot
            if mod(numel(plot_points),2) == 1
                plot_points = [plot_points numel(sig_cluster_identifier)]
            end
            % convert to timeline x axis (which is set in gca call above)
            plot_points = timeline(plot_points)
            % actually plot the lines
            for i = 1:2:numel(plot_points)
                plot(plot_points(i):plot_points(i+1), repmat(0.24, numel(plot_points(i):plot_points(i+1)),1), 'LineWidth', 4)
            end
        else
            plot_idx = timeline(plot_idx); 
            plot(plot_idx, repmat(0.24,numel(plot_idx),1), 'LineWidth', 4)
        end
    end
      
    % test over time interval, present stat in title
    stats_data = squeeze(mean(mean(classify_sample(working_condition, :, :, time_duration_classify),3),4)) - 0.25;
    [ci bootstats] = bootci(num_iterations, {@mean, stats_data}, 'type', 'per')
    stat_output = sum(bootstats<0)/num_iterations;
    title(['p = ' num2str(stat_output)]);
end

print -depsc -tiff -r300 -painters main_fig.eps




if 1
    
    % the correlation between target-elicited N2pc and target information is greater than the
    % correlation between distractor-elicited N2pc and target information
    [ci bootstats] = bootci(num_iterations, {@mean, rs(:,1) - rs(:,4)}, 'type', 'per')
    1 - sum(bootstats<0)/num_iterations
    
    % plot topo map N2pc
    topo = squeeze(mean(mean(ipsicon_sample(1,:,:,:),2),3))
    
    %LME
    tbl = table();
    [ic_targ, ic_targ_dl, ic_dist, ic_dist_tl, cl_targ, cl_targ_dl, cl_dist, cl_dist_tl] = deal([]);
    subs = [];
    for i = 1:numel(good_subs)
        ic_targ = [ic_targ; squeeze(mean(ipsicon_sample(1,i,:,time_duration_N2pc),4))'];
        cl_targ = [cl_targ; squeeze(mean(classify_sample(1,i,:,time_duration_classify),4))'];
        ic_targ_dl = [ic_targ_dl; squeeze(mean(ipsicon_sample(4,i,:,time_duration_N2pc),4))'];
        cl_targ_dl = [cl_targ_dl; squeeze(mean(classify_sample(4,i,:,time_duration_classify),4))'];
        ic_dist_tl = [ic_dist_tl; squeeze(mean(ipsicon_sample(3,i,:,time_duration_N2pc),4))'];
        cl_dist_tl = [cl_dist_tl; squeeze(mean(classify_sample(3,i,:,time_duration_classify),4))'];
        ic_dist = [ic_dist; squeeze(mean(ipsicon_sample(2,i,:,time_duration_N2pc),4))'];
        cl_dist = [cl_dist; squeeze(mean(classify_sample(2,i,:,time_duration_classify),4))'];
    end
    
    %unpacks across Ss first, then iterations
    ic_targ = double(ic_targ(:)); 
    cl_targ = double(cl_targ(:)); 
    ic_targ_dl = double(ic_targ_dl(:)); 
    cl_targ_dl = double(cl_targ_dl(:)); 
    ic_dist = double(ic_dist(:)); 
    cl_dist = double(cl_dist(:)); 
    ic_dist_tl = double(ic_dist_tl(:)); 
    cl_dist_tl = double(cl_dist_tl(:)); 
    
    ic = [ic_targ; ic_targ_dl];
    cl = [cl_targ; cl_targ_dl]; 
    % subjects
    temp = repmat((1:numel(good_subs)),size(ipsicon_sample,3),1)';
    subs = temp(:); 
    subs = [subs; subs]; 
    % condition
    cdn = [ones(1,numel(subs)./2) ones(1,(numel(subs)./2)) + 1]';
    
    tbl.ic = ic; 
    tbl.cl = cl; 
    tbl.subs = nominal(subs);
    tbl.cdn = nominal(cdn);
    
    mdl11a = fitlme(tbl, 'cl ~ 1 + (1|subs)')
    mdl22a = fitlme(tbl, 'cl ~ cdn + (1 + cdn|subs)')
    mdl1a = fitlme(tbl, 'cl ~ ic + (1|subs)')
    mdl1b = fitlme(tbl, 'cl ~ ic + cdn + (1 + ic + cdn|subs)')
    mdl1c = fitlme(tbl, 'cl ~ ic + cdn + ic:cdn + (1|subs)')
    mdl1d = fitlme(tbl, 'cl ~ ic + cdn + ic:cdn + (1 + ic|subs)')
    mdl1e = fitlme(tbl, 'cl ~ ic * cdn + (ic * cdn|subs)')
    mdl1f = fitlme(tbl, 'cl ~ ic * cdn + (1 + ic * cdn|subs)', 'FitMethod', 'REML')
    anova(mdl1f, 'df', 's')
    
    tbl = table();
    tbl.ic = ic_targ; 
    tbl.cl = cl_targ; 
    tbl.subs = nominal(subs(1:numel(subs)./2));
    mdl2a = fitlme(tbl, 'cl ~ ic + (1|subs)')
    mdl2b = fitlme(tbl, 'cl ~ ic + (1 + ic|subs)', 'FitMethod', 'REML')
    anova(mdl2b, 'df', 's')
    
    tbl = table();
    tbl.ic = ic_targ_dl; 
    tbl.cl = cl_targ_dl; 
    tbl.subs = nominal(subs(1:numel(subs)./2));
    mdl3a = fitlme(tbl, 'cl ~ ic + (1|subs)')
    mdl3b = fitlme(tbl, 'cl ~ ic + (1 + ic|subs)', 'FitMethod', 'REML')
    anova(mdl3b, 'df', 's')
    
    tbl = table();
    tbl.ic = ic_dist; 
    tbl.cl = cl_dist; 
    tbl.subs = nominal(subs(1:numel(subs)./2));
    mdl3a = fitlme(tbl, 'cl ~ ic + (1|subs)')
    mdl4b = fitlme(tbl, 'cl ~ ic + (1 + ic|subs)')
    anova(mdl4b)
    
    tbl = table();
    tbl.ic = ic_dist_tl; 
    tbl.cl = cl_dist_tl; 
    tbl.subs = nominal(subs(1:numel(subs)./2));
    mdl3a = fitlme(tbl, 'cl ~ ic + (1|subs)')
    mdl5b = fitlme(tbl, 'cl ~ ic + (1 + ic|subs)')
    anova(mdl5b)

    tbl = table();
    ic = [ic_targ; ic_dist];
    cl = [cl_targ; cl_dist]; 
    % subjects
    temp = repmat((1:numel(good_subs)),size(ipsicon_sample,3),1)';
    subs = temp(:); 
    subs = [subs; subs]; 
    % condition
    cdn = [ones(1,numel(subs)./2) ones(1,(numel(subs)./2)) + 1]';
    
    tbl.ic = ic; 
    tbl.cl = cl; 
    tbl.subs = nominal(subs);
    tbl.cdn = nominal(cdn);
    
    mdl1a = fitlme(tbl, 'cl ~ ic + (1|subs)')
    mdl1b = fitlme(tbl, 'cl ~ ic + cdn + (1|subs)')
    mdl1c = fitlme(tbl, 'cl ~ ic + cdn + ic:cdn + (1|subs)')
    mdl1d = fitlme(tbl, 'cl ~ ic + cdn + ic:cdn + (1 + ic|subs)')
    mdl1e = fitlme(tbl, 'cl ~ ic * cdn + (ic * cdn|subs)')
    mdl1f = fitlme(tbl, 'cl ~ ic * cdn + (1 + ic * cdn|subs)', 'FitMethod', 'ML', 'CovariancePattern', 'Diagonal')
    anova(mdl1f)
end

